import React from 'react';
import classNames from 'classnames';
import { IconType } from 'react-icons';

type Props = {
  id: string;
  label: string;
  icon: IconType;
  isDisabled?: boolean;
  url?: string;
  attrs?: Record<string, unknown>;
  onClick?(): void;
};

const MenuItem = ({ id, label, icon, url, isDisabled, attrs, onClick }: Props) => {
  const Icon = icon;

  return (
    <li
      key={id}
      data-test-id={id}
      className={classNames('bg-transparent py-2 px-3 text-xs first-of-type:pt-3 last-of-type:pb-3', {
        'text-gray-700 hover:text-primary-500 cursor-pointer': !isDisabled,
        'text-gray-400 hover:text-gray-400 cursor-not-allowed': isDisabled,
      })}
    >
      <a
        className={classNames('flex items-center text-inherit', { 'cursor-not-allowed': isDisabled })}
        href={isDisabled ? '#' : url}
        {...attrs}
        onClick={onClick}
      >
        <Icon
          size='1.1em'
          className={classNames('mr-2', isDisabled ? 'text-gray-400' : 'text-primary-500')}
        />
        {label}
      </a>
    </li>
  );
};

export default MenuItem;
