import React, { useState, useRef, useEffect } from "react"

type PopoverProps = {
  size?: "small" | "large"
}

export function Popover({ size = "small" }: PopoverProps) {
  const [open, setOpen] = useState(false)
  const ref = useRef<HTMLDivElement>(null)

  useEffect(() => {
    const handleClickOutside = (event: MouseEvent) => {
      if (ref.current && !ref.current.contains(event.target as Node)) {
        setOpen(false)
      }
    }
    document.addEventListener("mousedown", handleClickOutside)
    return () => document.removeEventListener("mousedown", handleClickOutside)
  }, [])

  const widthClass = size === "large" ? "w-[350px]" : "w-[250px]"

  return (
    <div className="relative inline-block text-left" ref={ref}>
      <button
        onClick={() => setOpen(!open)}
        className="inline-flex justify-center w-full rounded-md border border-gray-300 shadow-sm px-4 py-2 bg-white text-sm font-medium text-gray-700 hover:bg-gray-50"
      >
        Open {size === 'large' ? 'Large popover' : 'Small popover'}
      </button>
      {open && (
        <div
          className={`absolute z-10 mt-2 ${widthClass} rounded-md shadow-lg bg-white ring-1 ring-black ring-opacity-5 p-4 text-sm text-gray-700`}
        >
          <form className="flex flex-col gap-2">
            <label className="flex items-center gap-2">
              <input type="checkbox" className="form-checkbox" />
              Option 1
            </label>
            <label className="flex items-center gap-2">
              <input type="checkbox" className="form-checkbox" />
              Option 2
            </label>
            <label className="flex items-center gap-2">
              <input type="checkbox" className="form-checkbox" />
              Option 3
            </label>
          </form>
        </div>
      )}
    </div>
  )
}
